@@ -188,6 +188,39 @@ Ext.define('Traccar.view.map.MapMarkerController', {
         }
     },
 
+    animateMarker: function (marker, geometry, course) {
+        var start, end, duration, timeout, line, updatePosition, self;
+
+        start = marker.getGeometry().getCoordinates();
+        end = geometry.getCoordinates();
+        line = new ol.geom.LineString([start, end]);
+        duration = Traccar.Style.mapAnimateMarkerDuration;
+        timeout = Traccar.Style.mapAnimateMarkerTimeout;
+        self = this;
+
+        updatePosition = function (position, marker) {
+            var coordinate, style;
+            coordinate = marker.get('line').getCoordinateAt(position / (duration / timeout));
+            style = marker.getStyle();
+            marker.setGeometry(new ol.geom.Point(coordinate));
+            if (position < duration / timeout) {
+                setTimeout(updatePosition, timeout, position + 1, marker);
+            } else {
+                if (style.getImage().angle !== marker.get('nextCourse')) {
+                    self.rotateMarker(style, marker.get('nextCourse'));
+                }
+                marker.set('animating', false);
+            }
+        };
+
+        marker.set('line', line);
+        marker.set('nextCourse', course);
+        if (!marker.get('animating')) {
+            marker.set('animating', true);
+            updatePosition(1, marker);
+        }
+    },
+
     updateLatest: function (store, data) {
         var i, position, device, deviceStore;
 
@@ -210,15 +243,13 @@ Ext.define('Traccar.view.map.MapMarkerController', {
     },
 
     updateAccuracy: function (position, device) {
-        var center, radius, feature, mapView, projection, pointResolution;
-        mapView = this.getView().getMapView();
+        var center, radius, feature;
         feature = this.accuracyCircles[position.get('deviceId')];
 
         if (position.get('accuracy')) {
-            projection = mapView.getProjection();
             center = ol.proj.fromLonLat([position.get('longitude'), position.get('latitude')]);
-            pointResolution = ol.proj.getPointResolution(projection, mapView.getResolution(), center);
-            radius = position.get('accuracy') / ol.proj.Units.METERS_PER_UNIT.m * mapView.getResolution() / pointResolution;
+            radius = Ext.getStore('DistanceUnits').convertValue(
+                position.get('accuracy'), Traccar.app.getAttributePreference('distanceUnit'), true);
 
             if (feature) {
                 feature.getGeometry().setCenter(center);
@@ -249,11 +280,7 @@ Ext.define('Traccar.view.map.MapMarkerController', {
         deviceId = position.get('deviceId');
         if (deviceId in this.latestMarkers) {
             marker = this.latestMarkers[deviceId];
-            style = marker.getStyle();
-            if (style.getImage().angle !== position.get('course')) {
-                this.rotateMarker(style, position.get('course'));
-            }
-            marker.setGeometry(geometry);
+            this.animateMarker(marker, geometry, position.get('course'));
         } else {
             marker = new ol.Feature(geometry);
             marker.set('record', device);
